#ifndef NT2_INCLUDE_CONSTANTS_TWO_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_TWO_HPP_INCLUDED

#include <nt2/constant/include/constants/two.hpp>

#endif
